aboutsummaryrefslogtreecommitdiffstats
path: root/src/graphui/classes/com/jogamp/graph/ui/shapes/TexSeqButton.java
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2023-04-19 20:39:10 +0200
committerSven Gothel <[email protected]>2023-04-19 20:39:10 +0200
commit7a2f6bfdfadcaba1d6fecc2389ba7b91e927104a (patch)
tree44b91bb6771c042eef6ef8efe0c0c03bdd2eedbc /src/graphui/classes/com/jogamp/graph/ui/shapes/TexSeqButton.java
parent18c405bb970d34cbdeef4af9fa06e612d5edbffb (diff)
GraphUI {Round->Base}Button, denoting perpendicular or round corners (aka rectangle or oval shape)
- Button + BaseButton setter also pass this for chaining - Button {twoPassLabel->label}ZOffset, investigate whether z-offset still required (not if blending is enabled!) -
Diffstat (limited to 'src/graphui/classes/com/jogamp/graph/ui/shapes/TexSeqButton.java')
-rw-r--r--src/graphui/classes/com/jogamp/graph/ui/shapes/TexSeqButton.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/graphui/classes/com/jogamp/graph/ui/shapes/TexSeqButton.java b/src/graphui/classes/com/jogamp/graph/ui/shapes/TexSeqButton.java
index 87a86e706..4768b4974 100644
--- a/src/graphui/classes/com/jogamp/graph/ui/shapes/TexSeqButton.java
+++ b/src/graphui/classes/com/jogamp/graph/ui/shapes/TexSeqButton.java
@@ -35,7 +35,7 @@ import com.jogamp.graph.ui.GraphShape;
import com.jogamp.opengl.util.texture.TextureSequence;
/**
* An abstract GraphUI {@link TextureSequence} {@link RoundButton} {@link GraphShape}.
* <p>
* GraphUI is GPU based and resolution independent.
* </p>
@@ -44,7 +44,7 @@ import com.jogamp.opengl.util.texture.TextureSequence;
* To render it rectangular, {@link #setCorner(float)} to zero.
* </p>
*/
-public abstract class TexSeqButton extends RoundButton {
+public abstract class TexSeqButton extends BaseButton {
protected final TextureSequence texSeq;
public TexSeqButton(final int renderModes, final float width,
@@ -62,6 +62,6 @@ public abstract class TexSeqButton extends RoundButton {
@Override
protected void addShapeToRegion() {
- addRoundShapeToRegion( 0f );
+ addBaseShapeToRegion( 0f );
}
}
@@ -35,7 +35,7 @@ import com.jogamp.graph.ui.GraphShape;
import com.jogamp.opengl.util.texture.TextureSequence;
/**
- * An abstract GraphUI {@link TextureSequence} {@link RoundButton} {@link GraphShape}.
+ * An abstract GraphUI {@link TextureSequence} {@link BaseButton} {@link GraphShape}.
* <p>
* GraphUI is GPU based and resolution independent.